"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const dayjs = require("dayjs");
const yargs = require("yargs");
const utils_1 = require("../utils");
exports.command = "fake";
exports.desc = `-d -s -f : generate fake EXIF  and file atimestamps on a linear distribution between start and finish times`;
const env = utils_1.execute("printenv env");
exports.fake = (directory, startString, finishString) => __awaiter(this, void 0, void 0, function* () {
    // Initialize filesystem
    const files = yield utils_1.ls(directory);
    // Calculate date range and step size
    const start = dayjs(startString);
    const finish = dayjs(finishString);
    const difference = finish.diff(start);
    const increment = difference / files.length;
    // Debug Input Parameters
    utils_1.logger.debug(`Directory: ${directory}`);
    utils_1.logger.debug(`Start Time: ${start.format()}`);
    utils_1.logger.debug(`Finish Time: ${finish.format()}`);
    utils_1.logger.debug(`Increment: ${increment}`);
    // Loop over files and update Exif and file timestamp to new time
    let path = "";
    for (let i = 0; i < files.length; i++) {
        path = `${directory}/${files[i]}`;
        let oldFileDateName;
        if (env && env.toString().startsWith("CI")) {
            oldFileDateName = utils_1.execute(utils_1.osAgnosticFileDateTime(path));
        }
        else {
            oldFileDateName = utils_1.execute(utils_1.dumpFileDateName(path));
        }
        while (utils_1.execute(utils_1.setExifTime(start + i * increment, path)).includes("contains no Exif timestamp to change")) {
            utils_1.execute(utils_1.makeExifSection(path));
        }
        utils_1.execute(utils_1.setFileTimeToExifTime(path));
        let newExifTimeFileDateName;
        if (env && env.toString().startsWith("CI")) {
            newExifTimeFileDateName = utils_1.execute(utils_1.osAgnosticFileDateTime(path));
        }
        else {
            newExifTimeFileDateName = utils_1.execute(utils_1.dumpExifTimeFileDateName(path));
        }
        utils_1.logger.debug(`${oldFileDateName}=> \n${newExifTimeFileDateName}`);
    }
    utils_1.logger.debug("Done. 🍺");
});
exports.handler = () => __awaiter(this, void 0, void 0, function* () {
    try {
        var argv = yargs
            .option("d", {
            alias: "directory",
            demandOption: true,
            describe: "start time",
            type: "string"
        })
            .option("s", {
            alias: "start",
            demandOption: true,
            describe: "start time",
            type: "string"
        })
            .option("f", {
            alias: "finish",
            demandOption: true,
            describe: "finish time",
            type: "string"
        }).argv;
        exports.fake(argv.d, argv.s, argv.f);
    }
    catch (e) {
        utils_1.logger.error("[ERROR]", e);
    }
});
//# sourceMappingURL=fake.js.map