"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const fs = require("fs-extra");
const yargs = require("yargs");
const winston = require("winston");
__export(require("./jhead"));
exports.dateFormat = "YYYY-MM-DD HH:mm:ss:SSS";
exports.jheadTimeFormat = "YYYY:MM:DD-HH:mm:ss";
exports.jheadDateFormat = "YYYY:MM:DD";
const { colorize, combine, label, printf } = winston.format;
exports.logger = winston.createLogger({
    level: "debug",
    format: combine(colorize(), label({ label: "jheadx" }), printf(info => `[${info.label}][${info.level}]\n${info.message}`)),
    transports: [new winston.transports.Console()]
});
exports.jheadCmdFromArgs = () => {
    let args = process.argv;
    args.splice(0, 1);
    args[0] = "jhead";
    return args.join(" ");
};
exports.execute = (cmd) => {
    try {
        const result = child_process_1.execSync(cmd, { stdio: "pipe", encoding: "utf-8" });
        return result;
    }
    catch (e) {
        exports.logger.info(e.stdout);
        exports.logger.info(e.stderr);
    }
};
exports.handleFail = () => {
    exports.logger.info(yargs.help().version());
    const cmd = exports.jheadCmdFromArgs();
    exports.logger.info(`Now running: $ ${cmd}`);
    exports.execute(cmd);
};
exports.ls = (directory) => __awaiter(this, void 0, void 0, function* () {
    let files;
    try {
        files = yield fs
            .readdir(directory)
            .then(files => files.filter(file => !file.endsWith("DS_Store")));
    }
    catch (e) {
        exports.logger.error(`[ERROR] Failed to list files in directory: ${directory}. ${e}`);
    }
    return files;
});
//# sourceMappingURL=index.js.map